@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.887';
+our $VERSION = '1.902';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -94,6 +94,17 @@ sub import {
 ##
 ###############################################################################
 
+sub MCE::Flow::_guard::DESTROY {
+   my ($_pkg, $_id) = @{ $_[0] };
+
+   if (defined $_pkg && $_id eq "$$.$_tid") {
+      @{ $_[0] } = ();
+      MCE::Flow->finish($_pkg);
+   }
+
+   return;
+}
+
 sub init (@) {
 
    shift if (defined $_[0] && $_[0] eq 'MCE::Flow');
@@ -103,7 +114,9 @@ sub init (@) {
 
    @_ = ();
 
-   return;
+   defined wantarray
+      ? bless([$_pkg, "$$.$_tid"], MCE::Flow::_guard::)
+      : ();
 }
 
 sub finish (@) {
@@ -313,7 +326,7 @@ sub run (@) {
    my $_input_data; my $_max_workers = $_def->{$_pkg}{MAX_WORKERS};
    my $_r = ref $_[0];
 
-   if (@_ == 1 && $_r =~ /^(?:ARRAY|HASH|SCALAR|GLOB|FileHandle|IO::)/) {
+   if (@_ == 1 && $_r =~ /^(?:ARRAY|HASH|SCALAR|GLOB|FileHandle|IO::|Iterator::)/) {
       $_input_data = shift;
    }
 
@@ -482,7 +495,7 @@ MCE::Flow - Parallel flow model for building creative applications
 
 =head1 VERSION
 
-This document describes MCE::Flow version 1.887
+This document describes MCE::Flow version 1.902
 
 =head1 DESCRIPTION
 
@@ -811,12 +824,14 @@ Specify C<< Sereal => 0 >> to use Storable instead.
 =back
 
 The init function accepts a hash of MCE options. Unlike with MCE::Stream,
-both gather and bounds_only options may be specified when calling init
-(not shown below).
+both gather and bounds_only options may be specified (not shown below).
+
+In scalar context (API available since 1.897), call C<MCE::Flow->finish>
+automatically upon leaving the scope or program.
 
  use MCE::Flow;
 
- MCE::Flow->init(
+ my $guard = MCE::Flow->init(
     chunk_size => 1, max_workers => 4,
 
     user_begin => sub {
